@@ -325,17 +325,6 @@ sub ConvertTimezoneFunction {
     return $res;
 }
 
-sub _DateTimeIntervalFunction {
-    my $self = shift;
-    my %args = ( From => undef, To => undef, @_ );
-
-    return "EXTRACT(EPOCH FROM AGE($args{'To'}, $args{'From'}))";
-}
-
-sub HasSupportForNullsOrder {
-    return 1;
-}
-
 1;
 
 __END__
