@@ -209,13 +209,6 @@ sub ConvertTimezoneFunction {
     return $res;
 }
 
-sub _DateTimeIntervalFunction {
-    my $self = shift;
-    my %args = ( From => undef, To => undef, @_ );
-
-    return "strftime('%s',$args{'To'}) - strftime('%s',$args{'From'})";
-}
-
 1;
 
 __END__
