@@ -1324,7 +1324,7 @@ sub __Delete {
     my $QueryString = "DELETE FROM ". $self->Table . ' ' . $where;
    my $return = $self->_Handle->SimpleQuery($QueryString, @bind);
 
-    if (UNIVERSAL::isa('Class::ReturnValue', $return)) {
+    if (UNIVERSAL::isa($return, 'Class::ReturnValue')) {
         return ($return);
     } else {
         return(1); 
